'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Column = exports.Row = undefined;

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _react = require('react');

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

var _constants = require('../../util/constants');

var _createHigherOrderComponent = require('../../util/create-higher-order-component');

var _createHigherOrderComponent2 = _interopRequireDefault(_createHigherOrderComponent);

var _grid = require('../../util/grid');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var rowPropTypes = (0, _grid.createScreenSizePropTypes)(_constants.FLEX_GRID_ROW_CLASS_NAMES);
var columnPropTypes = (0, _grid.createScreenSizePropTypes)(_constants.FLEX_GRID_COLUMN_CLASS_NAMES);

rowPropTypes.expanded = _react.PropTypes.bool;
rowPropTypes.horizontalAlignment = _react.PropTypes.oneOf(_constants.FLEX_GRID_HORIZONTAL_ALIGNMENTS);
rowPropTypes.verticalAlignment = _react.PropTypes.oneOf(_constants.FLEX_GRID_VERTICAL_ALIGNMENTS);
columnPropTypes.shrink = _react.PropTypes.bool;
columnPropTypes.verticalAlignment = _react.PropTypes.oneOf(_constants.FLEX_GRID_VERTICAL_ALIGNMENTS);

var Row = exports.Row = (0, _createHigherOrderComponent2.default)({
  displayName: 'Row',
  propTypes: rowPropTypes,
  mapPropsToClassNames: function mapPropsToClassNames(_ref) {
    var expanded = _ref.expanded;
    var horizontalAlignment = _ref.horizontalAlignment;
    var verticalAlignment = _ref.verticalAlignment;
    var props = (0, _objectWithoutProperties3.default)(_ref, ['expanded', 'horizontalAlignment', 'verticalAlignment']);

    var classNames = (0, _grid.createScreenSizeClassNamesFromProps)(_constants.FLEX_GRID_ROW_CLASS_NAMES, props, _styles2.default);

    classNames[_styles2.default.row] = true;
    classNames[_styles2.default.expanded] = expanded;
    classNames[_styles2.default['align-' + horizontalAlignment]] = _constants.FLEX_GRID_HORIZONTAL_ALIGNMENTS.includes(horizontalAlignment);
    classNames[_styles2.default['align-' + verticalAlignment]] = _constants.FLEX_GRID_VERTICAL_ALIGNMENTS.includes(verticalAlignment);

    return classNames;
  },
  defaultComponentClass: 'div',
  collapseOnlyChild: false
});

var Column = exports.Column = (0, _createHigherOrderComponent2.default)({
  displayName: 'Column',
  propTypes: columnPropTypes,
  mapPropsToClassNames: function mapPropsToClassNames(_ref2) {
    var shrink = _ref2.shrink;
    var verticalAlignment = _ref2.verticalAlignment;
    var props = (0, _objectWithoutProperties3.default)(_ref2, ['shrink', 'verticalAlignment']);

    var classNames = (0, _grid.createScreenSizeClassNamesFromProps)(_constants.FLEX_GRID_COLUMN_CLASS_NAMES, props, _styles2.default);

    classNames[_styles2.default.column] = true;
    classNames[_styles2.default.shrink] = shrink;
    classNames[_styles2.default['align-' + verticalAlignment]] = _constants.FLEX_GRID_VERTICAL_ALIGNMENTS.includes(verticalAlignment);

    return classNames;
  },
  defaultComponentClass: 'div',
  collapseOnlyChild: false
});