'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isFinite = require('babel-runtime/core-js/number/is-finite');

var _isFinite2 = _interopRequireDefault(_isFinite);

var _values = require('babel-runtime/core-js/object/values');

var _values2 = _interopRequireDefault(_values);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

exports.createScreenSizeClassNames = createScreenSizeClassNames;
exports.createScreenSizePropTypes = createScreenSizePropTypes;
exports.createScreenSizeClassNamesFromProps = createScreenSizeClassNamesFromProps;

var _react = require('react');

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createScreenSizeClassNames() {
  var classNameMapping = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var classNames = [];

  (0, _keys2.default)(classNameMapping).forEach(function (baseClassName) {
    var _classNameMapping$bas = classNameMapping[baseClassName];
    var isNumber = _classNameMapping$bas.isNumber;
    var skipSmall = _classNameMapping$bas.skipSmall;


    _constants.SCREEN_SIZES.forEach(function (size) {
      if (!skipSmall || !_constants.SMALLER_SCREEN_SIZES.includes(size)) {
        var className = size + (baseClassName ? '-' + baseClassName : '');

        if (isNumber) {
          for (var column = _constants.GRID_COLUMN_MIN; column <= _constants.GRID_COLUMN_MAX; column += 1) {
            classNames.push(className + '-' + column);
          }
        } else {
          classNames.push(className);
        }
      }
    });
  });

  return classNames;
}

function createScreenSizePropTypes() {
  var classNameMapping = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var propTypes = {};

  _constants.SCREEN_SIZES.forEach(function (size) {
    (0, _values2.default)(classNameMapping).forEach(function (_ref) {
      var basePropName = _ref.basePropName;
      var isNumber = _ref.isNumber;
      var skipSmall = _ref.skipSmall;

      if (!skipSmall || !_constants.SMALLER_SCREEN_SIZES.includes(size)) {
        propTypes['' + size + basePropName] = isNumber ? _react.PropTypes.number : _react.PropTypes.bool;
      }
    });
  });

  return propTypes;
}

function createScreenSizeClassNamesFromProps() {
  var classNameMapping = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var props = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var styles = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

  var classNames = {};

  (0, _keys2.default)(classNameMapping).forEach(function (baseClassName) {
    var _classNameMapping$bas2 = classNameMapping[baseClassName];
    var basePropName = _classNameMapping$bas2.basePropName;
    var isNumber = _classNameMapping$bas2.isNumber;
    var skipSmall = _classNameMapping$bas2.skipSmall;


    _constants.SCREEN_SIZES.forEach(function (size) {
      if (!skipSmall || !_constants.SMALLER_SCREEN_SIZES.includes(size)) {
        var propName = '' + size + basePropName;
        var propValue = props[propName];
        var className = size + (baseClassName ? '-' + baseClassName : '');

        if (isNumber) {
          if (styles[className + '-' + propValue]) {
            classNames[styles[className + '-' + propValue]] = (0, _isFinite2.default)(propValue) && propValue >= _constants.GRID_COLUMN_MIN && propValue <= _constants.GRID_COLUMN_MAX;
          }
        } else if (styles[className]) {
          classNames[styles[className]] = propValue;
        }
      }
    });
  });

  return classNames;
}